# NOTE: Derived from blib/lib/Log/Agent.pm.
# Changes made here will be lost when autosplit again.
# See AutoSplit.pm.
package Log::Agent;

#line 160 "blib/lib/Log/Agent.pm (autosplit into blib/lib/auto/Log/Agent/logconfig.al)"
#
# logconfig
#
# Configure the logging system at the application level. By default, logging
# uses the Log::Agent::Default driver.
#
# Available options (case insensitive):
#
#   -PREFIX => string             logging prefix/tag to use, for Default agent
#   -DRIVER => object             object heir of Log::Agent::Driver
#   -TRACE => level               trace level
#   -DEBUG => level               debug level
#   -LEVEL => level               specifies common trace/debug level
#	-CONFESS => flag              whether to automatically confess on logdie
#	-CALLER => listref            info from caller to add and where
#
# For -CALLER, allowed keys are documented in the Log::Agent::Caller's make().
#
sub logconfig {
	my (%args) = @_;
	my $calldef;

	my %set = (
		-prefix			=> \$Prefix,		# Only for Default init
		-driver			=> \$Driver,
		-trace			=> \$Trace,
		-debug			=> \$Debug,
		-level			=> [\$Trace, \$Debug],
		-confess		=> \$Confess,
		-caller			=> \$calldef,
	);

	while (my ($arg, $val) = each %args) {
		my $vset = $set{lc($arg)};
		unless (ref $vset) {
			require Carp;
			Carp::croak("Unknown switch $arg");
		}
		if		(ref $vset eq 'SCALAR')		{ $$vset = $val }
		elsif	(ref $vset eq 'ARRAY')		{ map { $$_ = $val } @$vset }
		else								{ die "bug in logconfig" }
	}

	unless (defined $Driver) {
		require Log::Agent::Driver::Default;
		$Driver = Log::Agent::Driver::Default->make($Prefix);
	}

	$Prefix = $Driver->prefix;
	$Trace = level_from_prio($Trace) if defined $Trace && $Trace =~ /^\D+/;
	$Debug = level_from_prio($Debug) if defined $Trace && $Trace =~ /^\D+/;

	if (defined $calldef) {
		require Log::Agent::Caller;
		$Caller = Log::Agent::Caller->make(-offset => 2, @{$calldef});
	};
}

# end of Log::Agent::logconfig
1;
